asr.emasses
===========

.. automodule:: asr.emasses

   
   
   .. rubric:: Functions

   
   .. autofunction:: calculate_bs_along_emass_vecs
   .. autofunction:: check_soc
   .. autofunction:: convert_key_to_tuple
   .. autofunction:: create_columns_fnames
   .. autofunction:: custom_table
   .. autofunction:: em
   .. autofunction:: embands
   .. autofunction:: evalmodel
   .. autofunction:: fit
   .. autofunction:: get_2nd_order_extremum
   .. autofunction:: get_3rd_order_extremum
   .. autofunction:: get_bt_ks
   .. autofunction:: get_emass_dict_from_row
   .. autofunction:: get_extremum_type
   .. autofunction:: get_name
   .. autofunction:: get_ndims_from_row
   .. autofunction:: get_range
   .. autofunction:: get_vb_cb_indices
   .. autofunction:: kptsinsphere
   .. autofunction:: make_the_plots
   .. autofunction:: model
   .. autofunction:: nonsc_sphere
   .. autofunction:: preliminary_refine
   .. autofunction:: unpack_masses
   .. autofunction:: webpanel
   .. autofunction:: wideMAE
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   
   .. autoexception:: NoGapError
   
   